@@ -1,7 +1,7 @@
 #------------------------------------------------------------------------------
 # File:         Shortcuts.pm
 #
-# Description:  Definitions for tag shortcuts
+# Description:  ExifTool shortcut tags
 #
 # Revisions:    02/07/2004 - P. Harvey Moved out of Exif.pm
 #               09/15/2004 - P. Harvey Added D70Boring from Greg Troxel
@@ -158,7 +158,6 @@ $VERSION = '1.05';
 );
 
 # load user-defined shortcuts if available
-Image::ExifTool::LoadConfig();
 if (defined %Image::ExifTool::Shortcuts::UserDefined) {
     my $shortcut;
     foreach $shortcut (keys %Image::ExifTool::Shortcuts::UserDefined) {
@@ -177,7 +176,7 @@ __END__
 
 =head1 NAME
 
-Image::ExifTool::Shortcuts - Definitions for Image::ExifTool shortcuts
+Image::ExifTool::Shortcuts - ExifTool shortcut tags
 
 =head1 SYNOPSIS
 
